@@ -1,4 +1,4 @@
-from typing import ByteString, Dict, Iterable, Mapping, MutableMapping
+from typing import ByteString, Dict, Iterable, Mapping
 
 
 def decode_dict(data: Dict[bytes, bytes]) -> Dict[str, str]:
@@ -14,7 +14,7 @@ def decode_dict(data: Dict[bytes, bytes]) -> Dict[str, str]:
         elif isinstance(value, ByteString):
             ret[key] = value.decode()
         elif isinstance(value, Iterable):
-            ret[key] = value.__class__(
+            ret[key] = value.__new__(
                 (x.decode() if isinstance(x, bytes) else x for x in value)
             )
         else:
